---
title: Preferences
---

### Preferences

This section will go over how to utilize the preferences values you have defined.


#### Preference Interface

This section will go over the `\Anomaly\PreferencesModule\Preference\Contract\PreferenceInterface` class.


##### PreferenceInterface::field()

The `field` method returns the field type instance for the value or `null` if the value's field no longer exists.

###### Returns: `\Anomaly\Streams\Platform\Addon\FieldType\FieldType` or `null`

###### Example

    $setting = $settings->get('anomaly.module.files::max_parallel_uploads');

    if ($field = $setting->field()) {
        echo $field->getValue();
    }


#### Preference Repository

This section will go over the `\Anomaly\PreferencesModule\Preference\Contract\PreferenceInterface` class.


##### PreferenceRepositoryInterface::get()

The `get` method returns the preference instance.

###### Returns: `\Anomaly\PreferencesModule\Preference\Contract\PreferenceInterface`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$key

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The preference key.

</td>

</tr>

</tbody>

</table>

###### Example

    $max = $settings->value('anomaly.module.files::max_parallel_uploads');

    echo $max->getValue();


##### PreferenceRepositoryInterface::get()

The `get` method returns the preference instance.

###### Returns: `\Anomaly\PreferencesModule\Preference\Contract\PreferenceInterface`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$key

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The preference key.

</td>

</tr>

</tbody>

</table>

###### Example

    $max = $settings->value('anomaly.module.files::max_parallel_uploads');

    echo $max->getValue();


##### PreferenceRepositoryInterface::set()

The `set` method allows you to set a preference value.

<div class="alert alert-info">**Note:** Values are passed through the preference's field **modifier**.</div>

###### Returns: `boolean`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$key

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The preference key.

</td>

</tr>

<tr>

<td>

$value

</td>

<td>

true

</td>

<td>

mixed

</td>

<td>

none

</td>

<td>

The preference value.

</td>

</tr>

</tbody>

</table>


##### PreferenceRepositoryInterface::value()

The `value` method returns the value as the preference field type normally would with `getType`.

###### Returns: `mixed`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$key

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The preference key.

</td>

</tr>

<tr>

<td>

$default

</td>

<td>

false

</td>

<td>

mixed

</td>

<td>

null

</td>

<td>

The preference value.

</td>

</tr>

</tbody>

</table>

###### Example

    $value = $settings->value('anomaly.module.files::max_parallel_uploads', 5);


##### PreferenceRepositoryInterface::presenter()

The `presenter` method returns the preference value's field type presenter or `null` if the value's field no longer exists.

###### Returns: `\Anomaly\Streams\Platform\Addon\FieldType\FieldTypePresenter` or `null`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$key

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The preference key.

</td>

</tr>

</tbody>

</table>

###### Example

    $decorated = $settings->presenter('anomaly.module.files::max_parallel_uploads');

    echo $decorated->value;
